You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by ah...@apache.org on 2019/05/16 19:10:27 UTC

[commons-rng] 05/08: Make ignoring Dieharder sums test the default.

This is an automated email from the ASF dual-hosted git repository.

aherbert pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-rng.git

commit cbf304e37ee143370b949c8e398c479e86ca494f
Author: Alex Herbert <ah...@apache.org>
AuthorDate: Thu May 16 17:19:43 2019 +0100

    Make ignoring Dieharder sums test the default.
---
 .../apache/commons/rng/examples/stress/ResultsCommand.java   | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/commons-rng-examples/examples-stress/src/main/java/org/apache/commons/rng/examples/stress/ResultsCommand.java b/commons-rng-examples/examples-stress/src/main/java/org/apache/commons/rng/examples/stress/ResultsCommand.java
index bf2b85e..a884b20 100644
--- a/commons-rng-examples/examples-stress/src/main/java/org/apache/commons/rng/examples/stress/ResultsCommand.java
+++ b/commons-rng-examples/examples-stress/src/main/java/org/apache/commons/rng/examples/stress/ResultsCommand.java
@@ -106,10 +106,10 @@ class ResultsCommand implements Callable<Void> {
             description = "Output failed tests (not all formats).")
     private boolean showFailedTests;
 
-    /** The flag to ignore the diehard sums test. */
-    @Option(names = {"--ignore-sums"},
-            description = "Ignore diehard sums test.")
-    private boolean ignoreDiehardSums;
+    /** The flag to include the Dieharder sums test. */
+    @Option(names = {"--include-sums"},
+            description = "Include Dieharder sums test.")
+    private boolean includeDiehardSums;
 
     /**
      * The output mode for the results.
@@ -500,8 +500,8 @@ class ResultsCommand implements Callable<Void> {
         while (iter.hasNext()) {
             final String line = iter.next();
             if (DIEHARDER_FAILED_PATTERN.matcher(line).find()) {
-                // Option to ignore the flawed Dieharder sums test
-                if (ignoreDiehardSums && line.contains(DIEHARDER_SUMS)) {
+                // Optionally include the flawed Dieharder sums test
+                if (!includeDiehardSums && line.contains(DIEHARDER_SUMS)) {
                     continue;
                 }
                 final int index1 = line.indexOf('|');